summaryrefslogtreecommitdiffstats
path: root/source/World.cpp
diff options
context:
space:
mode:
authorTiger Wang <ziwei.tiger@hotmail.co.uk>2013-10-24 01:30:20 +0200
committerTiger Wang <ziwei.tiger@hotmail.co.uk>2013-10-24 01:30:20 +0200
commit4d2c810c64c38fd5530170d5c4d54956a5587fb2 (patch)
tree17c07b1a6eef15c83279f4530281bf7b986b06a3 /source/World.cpp
parentMerge remote-tracking branch 'upstream/master' (diff)
downloadcuberite-4d2c810c64c38fd5530170d5c4d54956a5587fb2.tar
cuberite-4d2c810c64c38fd5530170d5c4d54956a5587fb2.tar.gz
cuberite-4d2c810c64c38fd5530170d5c4d54956a5587fb2.tar.bz2
cuberite-4d2c810c64c38fd5530170d5c4d54956a5587fb2.tar.lz
cuberite-4d2c810c64c38fd5530170d5c4d54956a5587fb2.tar.xz
cuberite-4d2c810c64c38fd5530170d5c4d54956a5587fb2.tar.zst
cuberite-4d2c810c64c38fd5530170d5c4d54956a5587fb2.zip
Diffstat (limited to 'source/World.cpp')
-rw-r--r--source/World.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/World.cpp b/source/World.cpp
index ef56e7fe9..28c73f591 100644
--- a/source/World.cpp
+++ b/source/World.cpp
@@ -1533,7 +1533,7 @@ bool cWorld::WriteBlockArea(cBlockArea & a_Area, int a_MinBlockX, int a_MinBlock
-void cWorld::SpawnItemPickups(const cItems & a_Pickups, double a_BlockX, double a_BlockY, double a_BlockZ, double a_FlyAwaySpeed)
+void cWorld::SpawnItemPickups(const cItems & a_Pickups, double a_BlockX, double a_BlockY, double a_BlockZ, double a_FlyAwaySpeed, bool IsPlayerCreated)
{
MTRand r1;
a_FlyAwaySpeed /= 1000; // Pre-divide, so that we don't have to divide each time inside the loop
@@ -1545,7 +1545,7 @@ void cWorld::SpawnItemPickups(const cItems & a_Pickups, double a_BlockX, double
cPickup * Pickup = new cPickup(
a_BlockX, a_BlockY, a_BlockZ,
*itr, SpeedX, SpeedY, SpeedZ
);
Pickup->Initialize(this);
}
@@ -1555,13 +1555,13 @@ void cWorld::SpawnItemPickups(const cItems & a_Pickups, double a_BlockX, double
-void cWorld::SpawnItemPickups(const cItems & a_Pickups, double a_BlockX, double a_BlockY, double a_BlockZ, double a_SpeedX, double a_SpeedY, double a_SpeedZ)
+void cWorld::SpawnItemPickups(const cItems & a_Pickups, double a_BlockX, double a_BlockY, double a_BlockZ, double a_SpeedX, double a_SpeedY, double a_SpeedZ, bool IsPlayerCreated)
{
for (cItems::const_iterator itr = a_Pickups.begin(); itr != a_Pickups.end(); ++itr)
{
cPickup * Pickup = new cPickup(
a_BlockX, a_BlockY, a_BlockZ,
- *itr, (float)a_SpeedX, (float)a_SpeedY, (float)a_SpeedZ
+ *itr, IsPlayerCreated, (float)a_SpeedX, (float)a_SpeedY, (float)a_SpeedZ
);
Pickup->Initialize(this);
}
@@ -1545,7 +1545,7 @@ void cWorld::SpawnItemPickups(const cItems & a_Pickups, double a_BlockX, double
cPickup * Pickup = new cPickup(
a_BlockX, a_BlockY, a_BlockZ,
- *itr, SpeedX, SpeedY, SpeedZ
+ *itr, IsPlayerCreated, SpeedX, SpeedY, SpeedZ
);
Pickup->Initialize(this);